@@ -2,6 +2,7 @@
 import typing as T
 
 import pytest
+
 from docstring_parser.common import ParseError, RenderingStyle
 from docstring_parser.google import (
     GoogleParser,
@@ -446,7 +447,7 @@ def test_params() -> None:
 def test_attributes() -> None:
     """Test parsing attributes."""
     docstring = parse("Short description")
-    assert len(docstring.params) == 0
+    assert len(docstring.attrs) == 0
 
     docstring = parse(
         """
@@ -459,23 +460,24 @@ def test_attributes() -> None:
             ratio (Optional[float], optional): description 4
         """
     )
-    assert len(docstring.params) == 4
-    assert docstring.params[0].arg_name == "name"
-    assert docstring.params[0].type_name is None
-    assert docstring.params[0].description == "description 1"
-    assert not docstring.params[0].is_optional
-    assert docstring.params[1].arg_name == "priority"
-    assert docstring.params[1].type_name == "int"
-    assert docstring.params[1].description == "description 2"
-    assert not docstring.params[1].is_optional
-    assert docstring.params[2].arg_name == "sender"
-    assert docstring.params[2].type_name == "str"
-    assert docstring.params[2].description == "description 3"
-    assert docstring.params[2].is_optional
-    assert docstring.params[3].arg_name == "ratio"
-    assert docstring.params[3].type_name == "Optional[float]"
-    assert docstring.params[3].description == "description 4"
-    assert docstring.params[3].is_optional
+    assert len(docstring.params) == 0  # they are under a new section "attrs"
+    assert len(docstring.attrs) == 4
+    assert docstring.attrs[0].arg_name == "name"
+    assert docstring.attrs[0].type_name is None
+    assert docstring.attrs[0].description == "description 1"
+    assert not docstring.attrs[0].is_optional
+    assert docstring.attrs[1].arg_name == "priority"
+    assert docstring.attrs[1].type_name == "int"
+    assert docstring.attrs[1].description == "description 2"
+    assert not docstring.attrs[1].is_optional
+    assert docstring.attrs[2].arg_name == "sender"
+    assert docstring.attrs[2].type_name == "str"
+    assert docstring.attrs[2].description == "description 3"
+    assert docstring.attrs[2].is_optional
+    assert docstring.attrs[3].arg_name == "ratio"
+    assert docstring.attrs[3].type_name == "Optional[float]"
+    assert docstring.attrs[3].description == "description 4"
+    assert docstring.attrs[3].is_optional
 
     docstring = parse(
         """
@@ -487,15 +489,16 @@ def test_attributes() -> None:
             priority (int): description 2
         """
     )
-    assert len(docstring.params) == 2
-    assert docstring.params[0].arg_name == "name"
-    assert docstring.params[0].type_name is None
-    assert docstring.params[0].description == (
+    assert len(docstring.params) == 0
+    assert len(docstring.attrs) == 2
+    assert docstring.attrs[0].arg_name == "name"
+    assert docstring.attrs[0].type_name is None
+    assert docstring.attrs[0].description == (
         "description 1\nwith multi-line text"
     )
-    assert docstring.params[1].arg_name == "priority"
-    assert docstring.params[1].type_name == "int"
-    assert docstring.params[1].description == "description 2"
+    assert docstring.attrs[1].arg_name == "priority"
+    assert docstring.attrs[1].type_name == "int"
+    assert docstring.attrs[1].description == "description 2"
 
 
 def test_returns() -> None:
@@ -523,6 +526,10 @@ def test_returns() -> None:
     assert len(docstring.many_returns) == 1
     assert docstring.many_returns[0] == docstring.returns
 
+    # Writing the return section as "description with: a colon!" is inherently
+    # ambiguous, and this library is not designed to handle this ambiguity.
+    # Therefore, if you write "description with: a colon!", you are going to
+    # get "description with" as the return type.
     docstring = parse(
         """
         Short description
@@ -531,8 +538,8 @@ def test_returns() -> None:
         """
     )
     assert docstring.returns is not None
-    assert docstring.returns.type_name is None
-    assert docstring.returns.description == "description with: a colon!"
+    assert docstring.returns.type_name == "description with"
+    assert docstring.returns.description == "a colon!"
     assert docstring.many_returns is not None
     assert len(docstring.many_returns) == 1
     assert docstring.many_returns[0] == docstring.returns
@@ -607,6 +614,24 @@ def test_returns() -> None:
     assert docstring.many_returns[0] == docstring.returns
 
 
+def test_returns_edge_case_1() -> None:
+    """Test return section: edge case No. 1"""
+    # This edge case comes from: https://github.com/jsh9/pydoclint/issues/84
+    docstring = parse(
+        """
+        Short description
+        Returns:
+            dict[str, Any] | None: A description: with a colon
+        """
+    )
+    assert docstring.returns is not None
+    assert docstring.returns.type_name == "dict[str, Any] | None"
+    assert docstring.returns.description == "A description: with a colon"
+    assert docstring.many_returns is not None
+    assert len(docstring.many_returns) == 1
+    assert docstring.many_returns[0] == docstring.returns
+
+
 def test_yields() -> None:
     """Test parsing returns."""
     docstring = parse(
@@ -636,6 +661,10 @@ def test_yields() -> None:
     assert docstring.yields.description == "description"
     assert docstring.yields.is_generator is True
 
+    # Writing the return section as "description with: a colon!" is inherently
+    # ambiguous, and this library is not designed to handle this ambiguity.
+    # Therefore, if you write "description with: a colon!", you are going to
+    # get "description with" as the return type.
     docstring = parse(
         """
         Short description
@@ -644,8 +673,8 @@ def test_yields() -> None:
         """
     )
     assert docstring.yields is not None
-    assert docstring.yields.type_name is None
-    assert docstring.yields.description == "description with: a colon!"
+    assert docstring.yields.type_name == "description with"
+    assert docstring.yields.description == "a colon!"
     assert docstring.yields.is_generator is True
 
     docstring = parse(
@@ -711,8 +740,8 @@ def test_yields() -> None:
     )
     assert docstring.returns is not None
     assert docstring.yields is not None
-    assert docstring.yields.type_name == 'Optional[Mapping[str, List[int]]]'
-    assert docstring.returns.type_name == 'int'
+    assert docstring.yields.type_name == "Optional[Mapping[str, List[int]]]"
+    assert docstring.returns.type_name == "int"
 
 
 def test_raises() -> None:
