@@ -2,9 +2,87 @@
 import typing as T
 
 import pytest
+
+from docstring_parser import ParseError
 from docstring_parser.numpydoc import compose, parse
 
 
+@pytest.mark.parametrize(
+    "source",
+    [
+        "\n".join(
+            [
+                "This is a function",
+                "",
+                "Parameters",
+                "----------",
+                "    arg1 : str",
+                "    This is arg 1"
+            ]
+        ),
+        "\n".join(
+            [
+                "This is a function",
+                "",
+                "Parameters",
+                "----------",
+                "  arg1 : str",
+                "    This is arg 1"
+            ]
+        ),
+        "\n".join(
+            [
+                "This is a function",
+                "",
+                "Parameters",
+                "----------",
+                " arg1 : str",
+                "    This is arg 1"
+            ]
+        ),
+        "\n".join(
+            [
+                "This is a function",
+                "",
+                "Parameters",
+                "----------",
+                "    This is arg 1"
+            ]
+        ),
+        "\n".join(
+            [
+                "This is a function",
+                "",
+                "Returns",
+                "-------",
+                "    The return variable"
+            ]
+        ),
+        "\n".join(
+            [
+                "This is a function",
+                "",
+                "Yields",
+                "------",
+                "    Something yielded"
+            ]
+        ),
+        "\n".join(
+            [
+                "This is a function",
+                "",
+                "Raises",
+                "------",
+                "    Some error"
+            ]
+        ),
+    ],
+)
+def test_detect_formatting_error(source: str) -> None:
+    with pytest.raises(ParseError):
+        parse(source)
+
+
 @pytest.mark.parametrize(
     "source, expected",
     [
@@ -414,7 +492,7 @@ def test_params() -> None:
 def test_attributes() -> None:
     """Test parsing attributes."""
     docstring = parse("Short description")
-    assert len(docstring.params) == 0
+    assert len(docstring.attrs) == 0
 
     docstring = parse(
         """
@@ -432,23 +510,24 @@ def test_attributes() -> None:
             description 4
         """
     )
-    assert len(docstring.params) == 4
-    assert docstring.params[0].arg_name == "name"
-    assert docstring.params[0].type_name is None
-    assert docstring.params[0].description == "description 1"
-    assert not docstring.params[0].is_optional
-    assert docstring.params[1].arg_name == "priority"
-    assert docstring.params[1].type_name == "int"
-    assert docstring.params[1].description == "description 2"
-    assert not docstring.params[1].is_optional
-    assert docstring.params[2].arg_name == "sender"
-    assert docstring.params[2].type_name == "str"
-    assert docstring.params[2].description == "description 3"
-    assert docstring.params[2].is_optional
-    assert docstring.params[3].arg_name == "ratio"
-    assert docstring.params[3].type_name == "Optional[float]"
-    assert docstring.params[3].description == "description 4"
-    assert docstring.params[3].is_optional
+    assert len(docstring.params) == 0
+    assert len(docstring.attrs) == 4
+    assert docstring.attrs[0].arg_name == "name"
+    assert docstring.attrs[0].type_name is None
+    assert docstring.attrs[0].description == "description 1"
+    assert not docstring.attrs[0].is_optional
+    assert docstring.attrs[1].arg_name == "priority"
+    assert docstring.attrs[1].type_name == "int"
+    assert docstring.attrs[1].description == "description 2"
+    assert not docstring.attrs[1].is_optional
+    assert docstring.attrs[2].arg_name == "sender"
+    assert docstring.attrs[2].type_name == "str"
+    assert docstring.attrs[2].description == "description 3"
+    assert docstring.attrs[2].is_optional
+    assert docstring.attrs[3].arg_name == "ratio"
+    assert docstring.attrs[3].type_name == "Optional[float]"
+    assert docstring.attrs[3].description == "description 4"
+    assert docstring.attrs[3].is_optional
 
     docstring = parse(
         """
@@ -463,15 +542,16 @@ def test_attributes() -> None:
             description 2
         """
     )
-    assert len(docstring.params) == 2
-    assert docstring.params[0].arg_name == "name"
-    assert docstring.params[0].type_name is None
-    assert docstring.params[0].description == (
+    assert len(docstring.params) == 0
+    assert len(docstring.attrs) == 2
+    assert docstring.attrs[0].arg_name == "name"
+    assert docstring.attrs[0].type_name is None
+    assert docstring.attrs[0].description == (
         "description 1\nwith multi-line text"
     )
-    assert docstring.params[1].arg_name == "priority"
-    assert docstring.params[1].type_name == "int"
-    assert docstring.params[1].description == "description 2"
+    assert docstring.attrs[1].type_name == "int"
+    assert docstring.attrs[1].arg_name == "priority"
+    assert docstring.attrs[1].description == "description 2"
 
 
 def test_other_params() -> None:
@@ -521,6 +601,34 @@ def test_yields() -> None:
     assert docstring.meta[0].yield_name is None
     assert docstring.meta[0].is_generator
 
+    docstring = parse(
+        """
+        Short description
+        Yields
+        ------
+        int
+            description
+        str
+            another
+        """
+    )
+    assert len(docstring.meta) == 2
+    assert docstring.meta[0].args == ["yields"]
+    assert docstring.meta[0].type_name == "int"
+    assert docstring.meta[0].description == "description"
+    assert docstring.meta[0].yield_name is None
+    assert docstring.meta[0].is_generator
+    assert docstring.meta[1].args == ["yields"]
+    assert docstring.meta[1].type_name == "str"
+    assert docstring.meta[1].description == "another"
+    assert docstring.meta[1].yield_name is None
+    assert docstring.meta[1].is_generator
+    assert len(docstring.many_yields) == 2
+    assert docstring.many_yields[0].type_name == "int"
+    assert docstring.many_yields[0].description == "description"
+    assert docstring.many_yields[1].type_name == "str"
+    assert docstring.many_yields[1].description == "another"
+
 
 def test_returns() -> None:
     """Test parsing returns."""
